@@ -4,7 +4,7 @@
 **	Author:	David Oberholtzer, (daveo@obernet.com)
 **			Copyright (c)2001, David Oberholtzer and Measurisk.
 **	Date:	2001/03/23
-**	Rev:	$Id: API.h,v 1.2 2002/02/13 16:42:35 datadev Exp $
+**	Rev:	$Id: API.h,v 1.1 2003/06/18 02:01:57 daveo Exp daveo $
 **	Use:	Access to  FAME functions in other platforms.
 *****************************************************************************/
 
@@ -44,5 +44,5 @@ int		Cfmlerr();
 void	SetErrBuff();
 char	*newString(char *src);
 
-#endif	__FAMEHLI_FUNCS__
+#endif	// __FAMEHLI_FUNCS__
 
